@@ -16,6 +16,12 @@ OVERFLOW_ROW = -9999
 HEADER_FOOTER = 7777
 UNDEFINED_ROW = -8888
 
+KEEP_TYPE_NA = 0
+KEEP_TYPE_SPAN = 1
+KEEP_TYPE_START = 2
+KEEP_TYPE_MIDDLE = 3
+KEEP_TYPE_END = 4
+
 
 # noinspection PyPep8Naming
 class EnhancedTable(Table):
@@ -31,7 +37,7 @@ class EnhancedTable(Table):
                  col_widths=None, row_heights=None, style=None,
                  repeat_rows=0, repeat_cols=0, split_by_row=1, empty_table_action=None, ident=None,
                  h_align=None, v_align=None, normalized_data=0, cell_styles=None,
-                 _calc_row_splits=True, initial=False, pos_x=None, pos_y=None):
+                 _calc_row_splits=True, initial=False, pos_x=None, pos_y=None, colpositions=None):
         """
         Class Constructor.
 
@@ -87,13 +93,14 @@ class EnhancedTable(Table):
         self.data = table_data.get('row_data', [])
         self.variables = table_data.get('row_variables', [{} for _ in range(len(self.data))])
         self.properties = table_data.get('row_properties', [{} for _ in range(len(self.data))])
-        self.keep_with_next = table_data.get('keep_with_next', [False for _ in range(len(self.data))])
+        self.keep_with_next = table_data.get('keep_with_next', [KEEP_TYPE_NA for _ in range(len(self.data))])
         self.headers_index = table_data.get('headers_index', [False for _ in range(len(self.data))])
         self.footers_index = table_data.get('footers_index', [False for _ in range(len(self.data))])
         self.min_rows_after_header = min_rows_after_header
         self.min_rows_before_total = min_rows_before_total
         self.pos_x = pos_x
         self.pos_y = pos_y
+        self._colpositions = colpositions
 
         no_split_cmds = self._calc_nosplit_positions(_calc_row_splits)
 
@@ -133,10 +140,11 @@ class EnhancedTable(Table):
         footer_index = None
 
         split_at = 0  # from this point of view 0 is the first position where the table may *always* be split
-
-        for i, (rh, header_index, footer_index) in enumerate(zip(self._rowHeights,
-                                                                 self.headers_index,
-                                                                 self.footers_index)):
+        use_middle = True
+        for i, (rh, header_index, footer_index, keep_with_next) in enumerate(zip(self._rowHeights,
+                                                                                 self.headers_index,
+                                                                                 self.footers_index,
+                                                                                 self.keep_with_next)):
 
             number_of_header = 0
             if header_index is not None:
@@ -146,11 +154,17 @@ class EnhancedTable(Table):
             if footer_index is not None:
                 footer_height = self.footers[footer_index].rows_height
 
-            keep_with_next = self.keep_with_next[i]
             if h + rh > availHeight - footer_height:
                 break
-            if (self.initial or i > number_of_header) and n not in impossible and keep_with_next in [0, 3]:
-                split_at = n
+
+            if (self.initial or i > number_of_header) and n not in impossible and\
+                    keep_with_next in [KEEP_TYPE_NA, KEEP_TYPE_END, KEEP_TYPE_MIDDLE]:
+
+                if keep_with_next in [KEEP_TYPE_NA, KEEP_TYPE_END]:
+                    use_middle = False
+                    split_at = n
+                elif use_middle:
+                    split_at = n
             h = h + rh
             n += 1
 
@@ -308,7 +322,8 @@ class EnhancedTable(Table):
                            ident=ident,
                            min_rows_after_header=self.min_rows_after_header,
                            min_rows_before_total=self.min_rows_before_total,
-                           _calc_row_splits=False)
+                           _calc_row_splits=False,
+                           colpositions=self._colpositions)
 
         # copy the commands
 
@@ -438,7 +453,8 @@ class EnhancedTable(Table):
                            footers=self.footers,
                            min_rows_after_header=self.min_rows_after_header,
                            min_rows_before_total=self.min_rows_before_total,
-                           _calc_row_splits=False)
+                           _calc_row_splits=False,
+                           colpositions=self._colpositions)
 
         # Need to account for any header rows added when we call the following otherwise the row
         # styles will get out of step
