@@ -58,7 +58,7 @@ class ReportXML(object):
         (u'rsquo', u'’'),
     ]
 
-    def __init__(self, object_lookup=None, pager_kwargs=None, test_mode=False):
+    def __init__(self, object_lookup=None, pager_kwargs=None, test_mode=False, status_method=None):
         self.styles = {}
         if object_lookup is not None:
             self.object_lookup = object_lookup
@@ -79,6 +79,9 @@ class ReportXML(object):
         self.border_bottom_continuation = 0
         self.page_style = None
         self.test_mode = test_mode
+        self.status_method = status_method
+        self.held_variables = None
+        self.has_potential_xml_errors = False
 
         if pager_kwargs is None:
             self.pager_kwargs = {}
@@ -92,17 +95,38 @@ class ReportXML(object):
         self.background_image_remaining = background_image_remaining
         self.background_image_footer = background_image_footer
 
-        parser = etree.XMLParser(remove_blank_text=True, resolve_entities=False)
-
+        self.update_status("Loading")
+        self._has_potential_xml_errors = False
         if add_doctype:
             xml = self.get_doc_type() + xml
-        tree = etree.parse(StringIO(xml), parser)
+
+        try:
+            parser = etree.XMLParser(remove_blank_text=True, resolve_entities=True, recover=False)
+            tree = etree.parse(StringIO(xml), parser)
+        except etree.XMLSyntaxError:
+            self.has_potential_xml_errors = True
+            parser = etree.XMLParser(remove_blank_text=True, resolve_entities=True, recover=True)
+            tree = etree.parse(StringIO(xml), parser)
+
         root = tree.getroot()
         result = BytesIO()
         self.make_pdf(root, result)
         result.seek(0)
         return result
 
+    @property
+    def has_potential_xml_errors(self):
+        """Getter for has_potential_xml_errors property."""
+        return self._has_potential_xml_errors
+
+    @has_potential_xml_errors.setter
+    def has_potential_xml_errors(self, value):
+        """Setter for has_potential_xml_errors property."""
+        if not isinstance(value, bool):
+            raise ValueError("has_potential_xml_errors must be a boolean value.")
+
+        self._has_potential_xml_errors = value
+
     def get_object(self, object_id):
         if object_id in self.object_lookup.keys():
             return self.object_lookup[object_id]
@@ -113,6 +137,8 @@ class ReportXML(object):
                     return self.object_lookup[object_id]
             except ValueError:
                 pass
+                # if 'default' in self.object_lookup.keys():
+                #     return self.object_lookup['default']
         return None
 
     def make_pdf(self, root_element, file_buffer):
@@ -178,6 +204,7 @@ class ReportXML(object):
                               background_image_remaining=self.background_image_remaining,
                               background_image_footer=self.background_image_footer,
                               test_mode=self.test_mode,
+                              status_method=self.update_status,
                               **self.pager_kwargs)
 
     def canvasmaker(self, *args, **kwargs):
@@ -195,6 +222,7 @@ class ReportXML(object):
                               background_image_remaining=self.background_image_remaining,
                               background_image_footer=self.background_image_footer,
                               test_mode=self.test_mode,
+                              status_method=self.update_status,
                               **self.pager_kwargs,
                               **kwargs)
 
@@ -270,6 +298,8 @@ class ReportXML(object):
 
         rows_variables = []
         variables = {}
+        if self.held_variables is not None:
+            variables = {**self.held_variables}
 
         row_count = -1
         col_widths = []
@@ -436,6 +466,11 @@ class ReportXML(object):
                               v_align=v_align,
                               col_widths=new_column_widths,
                               initial=True)
+
+            if len(rows_variables) > 0 and len(rows_variables[-1]) > 0:
+                self.held_variables = rows_variables[-1]
+            else:
+                self.held_variables = None
         else:
             return None
 
@@ -478,8 +513,7 @@ class ReportXML(object):
         return x, y
 
     def process_tr(self, tr_element, data, styles, other_table_styles,
-                   row_heights, row_count, span, rows_variables, variables, col_widths, table_width, hidden_columns
-                   ,
+                   row_heights, row_count, span, rows_variables, variables, col_widths, table_width, hidden_columns,
                    held_cells=None, default_row_height=None, is_header_or_footer=False):
 
         max_row_span = 0
@@ -686,7 +720,7 @@ class ReportXML(object):
 
                             row_variables[currency_variable] = currency_value
                             variables[currency_variable] = currency_value
-                    if value is not None:
+                    if value is not None and value != '':
                         number_string = "%.2f" % (float(value) / 100.0)
                         display_object = '%s%s' % (symbol, intcomma_currency(number_string))
                     else:
@@ -1013,7 +1047,7 @@ class ReportXML(object):
 
             for xml_part in [xml[:pos]] + xml_parts:
                 working_xml = next_xml.encode() + xml_part
-                tags = re.findall(r'<[^<>]+>', working_xml.decode())
+                tags = re.findall(r'<[^<>]*>', working_xml.decode())
                 next_xml = ''
                 working_tags = []
                 for tag in tags:
@@ -1208,3 +1242,7 @@ class ReportXML(object):
     # noinspection PyMethodMayBeStatic
     def get_boolean_value(self, value):
         return value in ['1', 'True', 'yes']
+
+    def update_status(self, message):
+        if self.status_method is not None:
+            self.status_method(message)
